@@ -1,4 +1,6 @@
 from __future__ import annotations
+from platformdirs import user_runtime_dir
+from pathlib import Path
 
 import signal
 from dataclasses import dataclass
@@ -7,7 +9,8 @@ from podman.errors import APIError
 
 from h3daemon.env import get_env
 from h3daemon.namespace import Namespace
-from h3daemon.podman import close_podman, connect_podman, get_podman
+from h3daemon.podman import close_podman, connect_podman, get_podman, is_uri_online
+from h3daemon.podman_runtime import PodmanRuntime
 
 __all__ = ["H3Manager", "SysInfo"]
 
@@ -34,8 +37,27 @@ class H3Manager:
     def close(self):
         close_podman()
 
+    def _try_user_sock_file(self):
+        sock_file = (Path(user_runtime_dir("podman")) / "podman.sock").resolve()
+        uri = f"unix://{str(sock_file)}"
+        return sock_file.exists() or is_uri_online(uri)
+
     def __enter__(self) -> H3Manager:
-        connect_podman(get_env().H3DAEMON_URI)
+        env = get_env()
+        uri = env.H3DAEMON_URI if env.H3DAEMON_URI else ""
+
+        if not is_uri_online(uri):
+            # Try user sock file
+            sock_file = (Path(user_runtime_dir("podman")) / "podman.sock").resolve()
+            uri = f"unix://{str(sock_file)}"
+
+        if not is_uri_online(uri):
+            # Try Podman runtime
+            x = PodmanRuntime()
+            x.ensure_running()
+            uri = x.api_uri()
+
+        connect_podman(uri)
         return self
 
     def __exit__(self, exc_type, exc_value, traceback) -> None:
